@@ -143,7 +143,6 @@ package Sidef::Sys::Sys {
         my ($self, $text) = @_;
 
         if (defined($text)) {
-            $self->_is_string($text) || return;
             $text->print;
         }
 
@@ -157,7 +156,6 @@ package Sidef::Sys::Sys {
 
         if (@vars) {
             foreach my $var_ref (@vars) {
-                $self->_is_var_ref($var_ref) || return;
                 my $var = $var_ref->get_var;
                 print "$var->{name}: ";
                 chomp(my $input = <STDIN>);
@@ -208,6 +206,36 @@ package Sidef::Sys::Sys {
         CORE::bless $obj, $class;
     }
 
+    sub refaddr {
+        my ($self, $obj) = @_;
+        state $x = require Scalar::Util;
+        Sidef::Types::Number::Number->new(Scalar::Util::refaddr($obj));
+    }
+
+    sub reftype {
+        my ($self, $obj) = @_;
+        state $x = require Scalar::Util;
+        Sidef::Types::String::String->new(Scalar::Util::reftype($obj));
+    }
+
+    sub weaken {
+        my ($self, $obj) = @_;
+        state $x = require Scalar::Util;
+        Sidef::Types::Bool::Bool->new(Scalar::Util::weaken($obj));
+    }
+
+    sub isweak {
+        my ($self, $obj) = @_;
+        state $x = require Scalar::Util;
+        Sidef::Types::Bool::Bool->new(Scalar::Util::isweak($obj));
+    }
+
+    sub unweaken {
+        my ($self, $obj) = @_;
+        state $x = require Scalar::Util;
+        Sidef::Types::Bool::Bool->new(Scalar::Util::unweaken($obj));
+    }
+
     sub copy {
         my ($self, $obj) = @_;
         state $x = require Storable;
